Method: Minecraft::Tools.command

Defined in:
lib/minecraft/tools.rb

.command(opts) ⇒ Object

Generates a command for running the server with default settings including memory.

Parameters:

  • opts (Slop)

    Command line options from Slop, used for memory specification.



28
29
30
# File 'lib/minecraft/tools.rb', line 28

def self.command(opts)
  "java -Xmx#{opts[:max_memory] || "1024M"} -Xms#{opts[:min_memory] || "1024M"} -jar minecraft_server.jar nogui"
end